==> release-1.3.tar.gz: dsbdirect/app/src/main/java/godau/fynn/dsbdirect/Entry.java <==
/*
 * DSBDirect
 * Copyright (C) 2019 Fynn Godau
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * This software is not affiliated with heinekingmedia GmbH, the
 * developer of the DSB platform.
 */

package godau.fynn.dsbdirect;

public class Entry {
    private String mAffectedClass = "unknown";
    private String mLesson = "unknown";
    private String mReplacementTeacher = "unknown";
    private String mInfo = "unknown";
    private String mDate = "unkown";

    public Entry(String affectedClass, String lesson, String replacementTeacher, String info, String date) {
        mAffectedClass = affectedClass;
        mLesson = lesson;
        mReplacementTeacher = replacementTeacher;
        mInfo = info;
        mDate = date;
    }

    public String getAffectedClass() {
        return mAffectedClass;
    }

    public void setAffectedClass(String affectedClass) {
        mAffectedClass = affectedClass;
    }

    public String getLesson() {
        return mLesson;
    }

    public void setLesson(String lesson) {
        mLesson = lesson;
    }

    public String getReplacementTeacher() {
        return mReplacementTeacher;
    }

    public void setReplacementTeacher(String replacementTeacher) {
        mReplacementTeacher = replacementTeacher;
    }

    public String getInfo() {
        return mInfo;
    }

    public void setInfo(String info) {
        mInfo = info;
    }

    public String getDate() {
        return mDate;
    }

    public void setDate(String date) {
        mDate = date;
    }
}

==> release-1.8.1.tar.gz: dsbdirect/app/src/main/java/godau/fynn/dsbdirect/Entry.java <==
/*
 * DSBDirect
 * Copyright (C) 2019 Fynn Godau
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * This software is not affiliated with heinekingmedia GmbH, the
 * developer of the DSB platform.
 */

package godau.fynn.dsbdirect;

import android.support.annotation.Nullable;

import java.util.Date;

public class Entry {
    private String mAffectedClass = "unknown";
    private String mLesson = "unknown";
    private String mReplacementTeacher = "unknown";
    private String mInfo = "unknown";
    private Date mDate;

    public Entry(String affectedClass, String lesson, String replacementTeacher, String info, @Nullable Date date) {
        mAffectedClass = affectedClass;
        mLesson = lesson;
        mReplacementTeacher = replacementTeacher;
        mInfo = info;
        mDate = date;
    }

    public String getAffectedClass() {
        return mAffectedClass;
    }

    public void setAffectedClass(String affectedClass) {
        mAffectedClass = affectedClass;
    }

    public String getLesson() {
        return mLesson;
    }

    public void setLesson(String lesson) {
        mLesson = lesson;
    }

    public String getReplacementTeacher() {
        return mReplacementTeacher;
    }

    public void setReplacementTeacher(String replacementTeacher) {
        mReplacementTeacher = replacementTeacher;
    }

    public String getInfo() {
        return mInfo;
    }

    public void setInfo(String info) {
        mInfo = info;
    }

    public Date getDate() {
        return mDate;
    }

    public void setDate(Date date) {
        mDate = date;
    }
}
